doapfiend.model.CVSRepository

Package doapfiend :: Module model :: Class CVSRepository |
[hide private]
[frames] | no frames]

# Class CVSRepository

source code

            object --+
                     |
    doaplib.rdfSubject --+
                         |
                        CVSRepository

CVS repository class

Instance Methods | [hide private]
Inherited from `doaplib.rdfSubject`: `__delitem__`, `__getitem__`, `__init__`, `__repr__`, `md5_term_hash`, `n3` Inherited from `doaplib.rdfSubject` (private): `_ppo`, `_remove`, `_rename`, `_set_with_dict` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `doaplib.rdfSubject`: `ClassInstances`, `GetRandom`, `filter_by`, `get_by`, `query` Inherited from `doaplib.rdfSubject` (private): `_getdescriptor`

Class Variables | [hide private]
| rdf_type = `rdflib.URIRef('http://usefulinc.com/ns/doap#CVSRepo`...``
| anon_root = `rdfSingle(DOAP ['anon-root'])`
| cvs_browse = `rdfSingle(DOAP.browse)`
| module = `rdfSingle(DOAP.module)`
Inherited from `doaplib.rdfSubject`: `db`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### rdf_type Value:
      rdflib.URIRef('http://usefulinc.com/ns/doap#CVSRepository')